use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
ABEND
AFAICT
Brendan
Byrd
Champoux
Chris
ContributorsFromGit
David
Dist
Formattable
Golden
Graham
Gratipay
Greb
Knop
Mike
Miyagawa
PayPal
Perl
Plugin
RSRCHBOY
RSRCHBOY's
Randy
Stauner
Tatsuhiko
Weyl
Yanick
Zilla
codebase
coderef
cweyl
dagolden
formattable
gpg
haarg
implementers
ini
lib
metaclass
metaclasses
mikegrb
miyagawa
parameterization
parameterized
randy
subclasses
yanick
